
# $rcs = ' $Id: News.pm,v 1.2 2004/05/23 01:52:23 Daddy Exp Daddy $ ' ;

=head1 NAME

WWW::Search::News

=head1 DESCRIPTION

This is an empty package.  It only exists so that CPAN users can say
"install WWW::Search::News" and they'll get what they expect.  Well,
actually I'm not sure what they expect, but they'll get something
reasonable.

I also use it to control the version number of the distribution.

=head1 SEE ALSO

  WWW::Search::AP
  WWW::Search::Reuters
  WWW::Search::WashPost

=head1 AUTHOR

Martin Thurn

=cut

package WWW::Search::News;

use vars qw( $VERSION );
$VERSION = '1.072';

1;

__END__
